@@ -37,7 +37,19 @@ OpenAssessment.StudioView = function(runtime, element, server, data) {
         ])
     );
 
-    // Initialize the settings tab view
+    // Initialize the rubric tab view
+    this.rubricView = new OpenAssessment.EditRubricView(
+        $('#oa_rubric_editor_wrapper', this.element).get(0),
+        new OpenAssessment.Notifier([
+            studentTrainingListener,
+        ])
+    );
+
+    this.scheduleView = new OpenAssessment.EditScheduleView(
+        $('#oa_schedule_editor_wrapper', this.element).get(0)
+    );
+
+    // Initialize the settings and assessments steps tab views
     var staffAssessmentView = new OpenAssessment.EditStaffAssessmentView(
         $('#oa_staff_assessment_editor', this.element).get(0)
     );
@@ -45,10 +57,12 @@ OpenAssessment.StudioView = function(runtime, element, server, data) {
         $('#oa_student_training_editor', this.element).get(0)
     );
     var peerAssessmentView = new OpenAssessment.EditPeerAssessmentView(
-        $('#oa_peer_assessment_editor', this.element).get(0)
+        $('#oa_peer_assessment_editor', this.element).get(0),
+        $('#oa_schedule_editor_wrapper', this.element).get(0)
     );
     var selfAssessmentView = new OpenAssessment.EditSelfAssessmentView(
-        $('#oa_self_assessment_editor', this.element).get(0)
+        $('#oa_self_assessment_editor', this.element).get(0),
+        $('#oa_schedule_editor_wrapper', this.element).get(0)
     );
     var assessmentLookupDictionary = {};
     assessmentLookupDictionary[staffAssessmentView.getID()] = staffAssessmentView;
@@ -56,16 +70,12 @@ OpenAssessment.StudioView = function(runtime, element, server, data) {
     assessmentLookupDictionary[peerAssessmentView.getID()] = peerAssessmentView;
     assessmentLookupDictionary[selfAssessmentView.getID()] = selfAssessmentView;
 
-    this.settingsView = new OpenAssessment.EditSettingsView(
-        $('#oa_basic_settings_editor', this.element).get(0), assessmentLookupDictionary, data
+    this.assessmentsStepsView = new OpenAssessment.EditAssessmentsStepsView(
+        $('#oa_assessment_steps_editor_wrapper', this.element).get(0), assessmentLookupDictionary
     );
 
-    // Initialize the rubric tab view
-    this.rubricView = new OpenAssessment.EditRubricView(
-        $('#oa_rubric_editor_wrapper', this.element).get(0),
-        new OpenAssessment.Notifier([
-            studentTrainingListener,
-        ])
+    this.settingsView = new OpenAssessment.EditSettingsView(
+        $('#oa_basic_settings_editor', this.element).get(0), assessmentLookupDictionary, data
     );
 
     // Install the save and cancel buttons
@@ -104,7 +114,7 @@ OpenAssessment.StudioView.prototype = {
     initializeTabs: function() {
         // If this is the first editor that the user has opened, default to the prompt view.
         if (typeof(OpenAssessment.lastOpenEditingTab) === 'undefined') {
-            OpenAssessment.lastOpenEditingTab = 2;
+            OpenAssessment.lastOpenEditingTab = 0;
         }
         // Initialize JQuery UI Tabs, and activates the appropriate tab.
         $('.openassessment_editor_content_and_tabs', this.element)
@@ -198,16 +208,16 @@ OpenAssessment.StudioView.prototype = {
             feedback_default_text: view.rubricView.feedback_default_text(),
             criteria: view.rubricView.criteriaDefinition(),
             title: view.settingsView.displayName(),
-            submissionStart: view.settingsView.submissionStart(),
-            submissionDue: view.settingsView.submissionDue(),
-            assessments: view.settingsView.assessmentsDescription(),
+            submissionStart: view.scheduleView.submissionStart(),
+            submissionDue: view.scheduleView.submissionDue(),
+            assessments: view.assessmentsStepsView.assessmentsDescription(),
             textResponse: view.settingsView.textResponseNecessity(),
             fileUploadResponse: view.settingsView.fileUploadResponseNecessity(),
             fileUploadType: fileUploadType !== '' ? fileUploadType : null,
             fileTypeWhiteList: view.settingsView.fileTypeWhiteList(),
             latexEnabled: view.settingsView.latexEnabled(),
             leaderboardNum: view.settingsView.leaderboardNum(),
-            editorAssessmentsOrder: view.settingsView.editorAssessmentsOrder(),
+            editorAssessmentsOrder: view.assessmentsStepsView.editorAssessmentsOrder(),
             teamsEnabled: view.settingsView.teamsEnabled(),
             selectedTeamsetId: view.settingsView.teamset(),
         }).done(
@@ -248,9 +258,11 @@ OpenAssessment.StudioView.prototype = {
      **/
     validate: function() {
         var settingsValid = this.settingsView.validate();
+        var assessmentsStepsValid = this.assessmentsStepsView.validate();
+        var scheduleValid = this.scheduleView.validate();
         var rubricValid = this.rubricView.validate();
         var promptsValid = this.promptsView.validate();
-        return settingsValid && rubricValid && promptsValid;
+        return settingsValid && assessmentsStepsValid && scheduleValid && rubricValid && promptsValid;
     },
 
     /**
@@ -263,8 +275,12 @@ OpenAssessment.StudioView.prototype = {
      **/
     validationErrors: function() {
         return this.settingsView.validationErrors().concat(
-            this.rubricView.validationErrors().concat(
-                this.promptsView.validationErrors()
+            this.assessmentsStepsView.validationErrors().concat(
+                this.scheduleView.validationErrors().concat(
+                    this.rubricView.validationErrors().concat(
+                        this.promptsView.validationErrors()
+                    )
+                )
             )
         );
     },
@@ -274,6 +290,8 @@ OpenAssessment.StudioView.prototype = {
      **/
     clearValidationErrors: function() {
         this.settingsView.clearValidationErrors();
+        this.assessmentsStepsView.clearValidationErrors();
+        this.scheduleView.clearValidationErrors();
         this.rubricView.clearValidationErrors();
         this.promptsView.clearValidationErrors();
     },
